@@ -4,7 +4,8 @@ from oscar_webpay import views
 
 urlpatterns = patterns(
     '',
-    url(r'^webpay_redirect/$', views.WebPayRedirectView.as_view(), name='webpay-redirect'),
+    url(r'^webpay_redirect/(?P<return_url_name>\w|\-)+/(?P<final_url_name>\w|\-)+/$', views.WebPayRedirectView.as_view(),
+        name='webpay-redirect'),
     url(r'^webpay_form/$', views.WebPayRedirectForm.as_view(), name='webpay-form'),
     url(r'^webpay_success/$', views.WebPayPaymentSuccessView.as_view(), name='webpay-success'),
     url(r'^webpay_place_order/$', views.WebPayPaymentSuccessView.as_view(returning_from_webpay=False),
